---
hide-toc: true
---

```{include} ../README.md
:relative-docs: docs/
:relative-images:
```


```{toctree}
:caption: API Reference
:hidden:

reference/client
reference/fsspec
```

```{toctree}
:hidden:
reference/cli
```

```{toctree}
:caption: Development
:hidden:

contributing
License: MIT <https://github.com/skshetry/webdav4/blob/main/LICENSE>
Bug Reports <https://github.com/skshetry/webdav4/issues>
Source Code <https://github.com/skshetry/webdav4>
```
